summaryrefslogtreecommitdiffstats
path: root/juk/dynamicplaylist.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/dynamicplaylist.h')
-rw-r--r--juk/dynamicplaylist.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/juk/dynamicplaylist.h b/juk/dynamicplaylist.h
index 3e6e2c4b..20e496d0 100644
--- a/juk/dynamicplaylist.h
+++ b/juk/dynamicplaylist.h
@@ -31,8 +31,8 @@ public:
*/
DynamicPlaylist(const PlaylistList &lists,
PlaylistCollection *collection,
- const QString &name = QString::null,
- const QString &iconName = "midi",
+ const TQString &name = TQString::null,
+ const TQString &iconName = "midi",
bool setupPlaylist = true,
bool synchronizePlaying = false);
@@ -55,7 +55,7 @@ public slots:
* it can synchronize the playing item with the one that playlist it was
* create from.
*/
- void lower(QWidget *top = 0);
+ void lower(TQWidget *top = 0);
protected:
/**
@@ -72,12 +72,12 @@ protected:
virtual PlaylistItemList items();
/**
* Reimplemented from QWidget. Here it updates the list of items (when
* appropriate) as the widget is shown.
*/
- virtual void showEvent(QShowEvent *e);
+ virtual void showEvent(TQShowEvent *e);
- virtual void paintEvent(QPaintEvent *e);
+ virtual void paintEvent(TQPaintEvent *e);
/**
* Updates the items (unconditionally). This should be reimplemented in
@@ -100,7 +100,7 @@ private slots:
void slotUpdateItems();
private:
- QValueList<PlaylistObserver *> m_observers;
+ TQValueList<PlaylistObserver *> m_observers;
PlaylistItemList m_siblings;
PlaylistList m_playlists;
bool m_dirty;
@@ -72,12 +72,12 @@ protected:
virtual PlaylistItemList items();
/**
- * Reimplemented from QWidget. Here it updates the list of items (when
+ * Reimplemented from TQWidget. Here it updates the list of items (when
* appropriate) as the widget is shown.
*/